summaryrefslogtreecommitdiff
path: root/Source/Plugins/Plugin_VideoSoftware/Src/Win32.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'Source/Plugins/Plugin_VideoSoftware/Src/Win32.cpp')
-rw-r--r--Source/Plugins/Plugin_VideoSoftware/Src/Win32.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/Source/Plugins/Plugin_VideoSoftware/Src/Win32.cpp b/Source/Plugins/Plugin_VideoSoftware/Src/Win32.cpp
index 5b374f8ca1..1ce1763454 100644
--- a/Source/Plugins/Plugin_VideoSoftware/Src/Win32.cpp
+++ b/Source/Plugins/Plugin_VideoSoftware/Src/Win32.cpp
@@ -162,8 +162,8 @@ LRESULT CALLBACK WndProc( HWND hWnd, UINT iMsg, WPARAM wParam, LPARAM lParam )
// Pressing Esc switches to Windowed mode from Fullscreen mode
ToggleFullscreen(hWnd);
}
- // And stops the emulation when already in Windowed mode
- PostMessage(m_hMain, WM_USER, WM_USER_STOP, 0);
+ // And pause the emulation when already in Windowed mode
+ PostMessage(m_hMain, WM_USER, WM_USER_PAUSE, 0);
break;
}
g_VideoInitialize.pKeyPress(LOWORD(wParam), GetAsyncKeyState(VK_SHIFT) != 0, GetAsyncKeyState(VK_CONTROL) != 0);